<?php
namespace SaaslandCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;



// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}



/**
 * Text Typing Effect
 *
 * Elementor widget for text typing effect.
 *
 * @since 1.7.0
 */
class Saasland_map3 extends Widget_Base {

    public function get_name() {
        return 'saasland_map3';
    }

    public function get_title() {
        return __( 'Saasland Map (Hosting)', 'saasland-core' );
    }

    public function get_icon() {
        return 'eicon-google-maps';
    }

    public function get_categories() {
        return [ 'saasland-elements' ];
    }

    protected function _register_controls() {

        // ------------------------------  Title Section ------------------------------ //
        $this->start_controls_section(
            'title_sec', [
                'label' => __( 'Title', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'title', [
                'label' => esc_html__( 'Title', 'saasland-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => 'Service your customers around <br> the world from 15 regions.'
            ]
        );

        $this->add_control(
            'color_title', [
                'label' => __( 'Text Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hosting_title h2' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'typography_title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '
                    {{WRAPPER}} .hosting_title h2',
            ]
        );


        $this->end_controls_section(); // End Title

        // ------------------------------  Subtitle Section ------------------------------ //
        $this->start_controls_section(
            'title_sec', [
                'label' => esc_html__( 'Title', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'subtitle', [
                'label' => esc_html__( 'Subtitle', 'saasland-core' ),
                'type' => Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'color_subtitle', [
                'label' => __( 'Text Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hosting_title p' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'typography_subtitle',
                'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                'selector' => '
                    {{WRAPPER}} .hosting_title p',
            ]
        );

        $this->end_controls_section(); // End Subtitle Section

        // ------------------------------  Map Section ------------------------------ //
        $this->start_controls_section(
            'map_sec', [
                'label' => esc_html__( 'Map', 'saasland-core' ),
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'place_name', [
                'label' => esc_html__( 'Place Name', 'saasland-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Dhaka, Bangladesh'
            ]
        );


        $repeater->end_controls_tab();

        $this->add_control(
            'maps', [
                'label' => esc_html__( 'Map', 'saasland-core' ),
                'type' => Controls_Manager::REPEATER,
                'title_field' => '{{{ place_name }}}',
                'fields' => $repeater->get_controls(),
            ]
        );

        $this->end_controls_section(); // End Map Section


        /**
         * Style Tab
         * ------------------------------ Style Title ------------------------------
         *
         */
        $this->start_controls_section(
            'bg_style_sec',
            [
                'label' => __( 'Background Style', 'saasland-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'bg_img', [
                'label' => esc_html__( 'Background Image', 'saasland-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => plugins_url('/images/home-hosting/region_map.png', __FILE__)
                ]
            ]
        );

        $this->add_control(
            'bg_color', [
                'label' => __( 'Background Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .h_map_area' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
            'map_style_sec',
            [
                'label' => __( 'Map Style', 'saasland-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'text_color', [
                'label' => __( 'Text Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .h_map ul li .place_name' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'text_bg_color', [
                'label' => __( 'Background Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .h_map ul li .place_name' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'border_color', [
                'label' => __( 'Border Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .h_map ul li .place_name:before' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'round_color', [
                'label' => __( 'Round Color 01', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .h_map ul li .round' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'round_color2', [
                'label' => __( 'Round Color 02', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .h_map ul li .round:before, .h_map ul li .round:after' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'wave_color', [
                'label' => __( 'Wave Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .h_map ul li .round .dot' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();



    }

    protected function render() {
        $settings = $this->get_settings();
        $maps = $settings['maps'];
        ?>
        <section class="h_map_area">
            <div class="container">
                <div class="hosting_title text-center">
                    <?php if (!empty($settings['title'])) : ?>
                        <h2><?php echo wp_kses_post(nl2br($settings['title'])) ?></h2>
                    <?php endif; ?>
                    <?php if (!empty($settings['subtitle'])) : ?>
                        <?php echo wpautop($settings['subtitle']) ?>
                    <?php endif; ?>
                </div>
                <div class="h_map" style="background: url(<?php echo esc_url($settings['bg_img']['url']) ?>) no-repeat scroll center top;">
                    <ul class="list-unstyled">
                        <?php
                        if (!empty($maps)) {
                            foreach ($maps as $map) {
                                ?>
                                <?php if (!empty($map['place_name'])) : ?>
                                    <li>
                                        <div class="place_name"><?php echo esc_html($map['place_name']) ?></div>
                                        <div class="round"><div class="dot"></div></div>
                                    </li>
                                <?php endif; ?>
                                <?php
                            }
                        }
                        ?>

                    </ul>
                </div>
            </div>
        </section>
        <?php
    }

}